Timeflux Plux plugin
====================

This plugin provides a driver to connect to `Plux <https://biosignalsplux.com/>`__ devices.

When connecting to the device for the first time, use the following pairing code: `123`.

Installation
------------

First, make sure that `Timeflux <https://github.com/timeflux/timeflux>`__ is installed.

You can then install this plugin in the `timeflux` environment:

::

    $ conda activate timeflux
    $ pip install timeflux_plux

Documentation
-------------

The API documentation and examples can be found `here <https://doc.timeflux.io/projects/timeflux-plux/>`__.